[devel] Imported from libpng-1.5.0beta08.tar
diff --git a/ANNOUNCE b/ANNOUNCE
index c473b07..8355980 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
 
-Libpng 1.5.0beta07 - February 19, 2010
+Libpng 1.5.0beta08 - February 19, 2010
 
 This is not intended to be a public release.  It will be replaced
 within a few weeks by a public version or by another test version.
@@ -9,20 +9,20 @@
 Source files with LF line endings (for Unix/Linux) and with a
 "configure" script
 
-   1.5.0beta07.tar.xz (LZMA-compressed, recommended)
-   1.5.0beta07.tar.gz
-   1.5.0beta07.tar.bz2
+   1.5.0beta08.tar.xz (LZMA-compressed, recommended)
+   1.5.0beta08.tar.gz
+   1.5.0beta08.tar.bz2
 
 Source files with CRLF line endings (for Windows), without the
 "configure" script
 
-   lp150b07.zip
-   lp150b07.7z
+   lp150b08.zip
+   lp150b08.7z
 
 Other information:
 
-   1.5.0beta07-README.txt
-   1.5.0beta07-LICENSE.txt
+   1.5.0beta08-README.txt
+   1.5.0beta08-LICENSE.txt
 
 Changes since the last public release (1.4.1):
 
@@ -53,7 +53,9 @@
   Fixed type declaration of png_get_chunk_malloc_max() in pngget.c (Daisuke
     Nishikawa)
 
-version 1.5.0beta07 [February 19, 2010]
+version 1.5.0beta07 [omitted]
+
+version 1.5.0beta08 [February 19, 2010]
   Changed #ifdef PNG_NO_STDIO_SUPPORTED to #ifdef PNG_NO_CONSOLE_IO_SUPPORTED
     wherever png_snprintf() is used to construct error and warning messages.
   Noted in scripts/makefile.mingw that it expects to be run under MSYS.
diff --git a/CHANGES b/CHANGES
index 495bb07..2dbdbd8 100644
--- a/CHANGES
+++ b/CHANGES
@@ -2530,9 +2530,12 @@
   Fixed type declaration of png_get_chunk_malloc_max() in pngget.c (Daisuke
     Nishikawa)
 
-version 1.5.0beta07 [February 19, 2010]
+version 1.5.0beta07 [omitted]
+
+version 1.5.0beta08 [February 19, 2010]
   Changed #ifdef PNG_NO_STDIO_SUPPORTED to #ifdef PNG_NO_CONSOLE_IO_SUPPORTED
     wherever png_snprintf() is used to construct error and warning messages.
+  Noted in scripts/makefile.mingw that it expects to be run under MSYS.
   Removed obsolete unused MMX-querying support from contrib/gregbook
   Added exported png_longjmp() function.
   Removed the AIX redefinition of jmpbuf in png.h
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 4f2e52f..b86da69 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -125,6 +125,10 @@
 
 add_definitions(-DPNG_CONFIGURE_LIBPNG)
 
+if (_AIX)
+  add_definitions(-D_ALLSOURCE)
+endif(_AIX)
+
 if(MSVC)
   add_definitions(-DPNG_NO_MODULEDEF -D_CRT_SECURE_NO_DEPRECATE)
 endif(MSVC)
@@ -209,7 +213,7 @@
 # SET UP LINKS
 if(PNG_SHARED)
   set_target_properties(${PNG_LIB_NAME} PROPERTIES
-#   VERSION 15.${PNGLIB_RELEASE}.1.5.0beta07
+#   VERSION 15.${PNGLIB_RELEASE}.1.5.0beta08
     VERSION 15.${PNGLIB_RELEASE}.0
     SOVERSION 15
     CLEAN_DIRECT_OUTPUT 1)
diff --git a/INSTALL b/INSTALL
index 43dcbd3..a4e1e44 100644
--- a/INSTALL
+++ b/INSTALL
@@ -1,5 +1,5 @@
 
-Installing libpng version 1.5.0beta07 - February 19, 2010
+Installing libpng version 1.5.0beta08 - February 19, 2010
 
 On Unix/Linux and similar systems, you can simply type
 
@@ -46,7 +46,7 @@
 correspond to the version of zlib that's installed.
 
 You can rename the directories that you downloaded (they
-might be called "libpng-1.5.0beta07" or "libpng15" and "zlib-1.2.3"
+might be called "libpng-1.5.0beta08" or "libpng15" and "zlib-1.2.3"
 or "zlib123") so that you have directories called "zlib" and "libpng".
 
 Your directory structure should look like this:
diff --git a/LICENSE b/LICENSE
index fe021d3..5738e6b 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.0beta07, February 19, 2010, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.0beta08, February 19, 2010, are
 Copyright (c) 2004, 2006-2007 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
diff --git a/Makefile.am b/Makefile.am
index 5519a4d..3409dc9 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -73,7 +73,7 @@
 	${srcdir}/contrib/pngsuite/* \
 	${srcdir}/contrib/visupng/* \
 	$(TESTS) \
-	example.c libpng-1.5.0beta07.txt
+	example.c libpng-1.5.0beta08.txt
 
 CLEANFILES= pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers \
 libpng.sym
diff --git a/Makefile.in b/Makefile.in
index ef1db28..2b02174 100644
--- a/Makefile.in
+++ b/Makefile.in
@@ -333,7 +333,7 @@
 	${srcdir}/contrib/pngsuite/* \
 	${srcdir}/contrib/visupng/* \
 	$(TESTS) \
-	example.c libpng-1.5.0beta07.txt
+	example.c libpng-1.5.0beta08.txt
 
 CLEANFILES = pngout.png libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.pc libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@-config libpng.vers \
 libpng.sym
diff --git a/README b/README
index 8632281..90105c8 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.0beta07 - February 19, 2010 (shared library 15.0)
+README for libpng version 1.5.0beta08 - February 19, 2010 (shared library 15.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
@@ -185,9 +185,9 @@
        makefile.std     =>  Generic UNIX makefile (cc, creates static
                             libpng.a)
        makefile.elf     =>  Linux/ELF makefile symbol versioning,
-                            gcc, creates libpng15.so.15.1.5.0beta07)
+                            gcc, creates libpng15.so.15.1.5.0beta08)
        makefile.linux   =>  Linux/ELF makefile
-                            (gcc, creates libpng15.so.15.1.5.0beta07)
+                            (gcc, creates libpng15.so.15.1.5.0beta08)
        makefile.gcc     =>  Generic makefile (gcc, creates static libpng.a)
        makefile.knr     =>  Archaic UNIX Makefile that converts files with
                             ansi2knr (Requires ansi2knr.c from
@@ -209,12 +209,12 @@
        makefile.openbsd =>  OpenBSD makefile
        makefile.sgi     =>  Silicon Graphics IRIX (cc, creates static lib)
        makefile.sggcc   =>  Silicon Graphics
-                            (gcc, creates libpng15.so.15.1.5.0beta07)
+                            (gcc, creates libpng15.so.15.1.5.0beta08)
        makefile.sunos   =>  Sun makefile
        makefile.solaris =>  Solaris 2.X makefile
-                            (gcc, creates libpng15.so.15.1.5.0beta07)
+                            (gcc, creates libpng15.so.15.1.5.0beta08)
        makefile.so9     =>  Solaris 9 makefile
-                            (gcc, creates libpng15.so.15.1.5.0beta07)
+                            (gcc, creates libpng15.so.15.1.5.0beta08)
        makefile.32sunu  =>  Sun Ultra 32-bit makefile
        makefile.64sunu  =>  Sun Ultra 64-bit makefile
        makefile.sco     =>  For SCO OSr5  ELF and Unixware 7 with Native cc
diff --git a/configure b/configure
index fe9565c..e2d887a 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.65 for libpng 1.5.0beta07.
+# Generated by GNU Autoconf 2.65 for libpng 1.5.0beta08.
 #
 # Report bugs to <png-mng-implement@lists.sourceforge.net>.
 #
@@ -701,8 +701,8 @@
 # Identity of this package.
 PACKAGE_NAME='libpng'
 PACKAGE_TARNAME='libpng'
-PACKAGE_VERSION='1.5.0beta07'
-PACKAGE_STRING='libpng 1.5.0beta07'
+PACKAGE_VERSION='1.5.0beta08'
+PACKAGE_STRING='libpng 1.5.0beta08'
 PACKAGE_BUGREPORT='png-mng-implement@lists.sourceforge.net'
 PACKAGE_URL=''
 
@@ -1432,7 +1432,7 @@
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures libpng 1.5.0beta07 to adapt to many kinds of systems.
+\`configure' configures libpng 1.5.0beta08 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1502,7 +1502,7 @@
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of libpng 1.5.0beta07:";;
+     short | recursive ) echo "Configuration of libpng 1.5.0beta08:";;
    esac
   cat <<\_ACEOF
 
@@ -1607,7 +1607,7 @@
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-libpng configure 1.5.0beta07
+libpng configure 1.5.0beta08
 generated by GNU Autoconf 2.65
 
 Copyright (C) 2009 Free Software Foundation, Inc.
@@ -2032,7 +2032,7 @@
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by libpng $as_me 1.5.0beta07, which was
+It was created by libpng $as_me 1.5.0beta08, which was
 generated by GNU Autoconf 2.65.  Invocation command line was
 
   $ $0 $@
@@ -2840,7 +2840,7 @@
 
 # Define the identity of the package.
  PACKAGE='libpng'
- VERSION='1.5.0beta07'
+ VERSION='1.5.0beta08'
 
 
 cat >>confdefs.h <<_ACEOF
@@ -2904,7 +2904,7 @@
 
 
 
-PNGLIB_VERSION=1.5.0beta07
+PNGLIB_VERSION=1.5.0beta08
 PNGLIB_MAJOR=1
 PNGLIB_MINOR=5
 PNGLIB_RELEASE=0
@@ -12033,7 +12033,7 @@
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by libpng $as_me 1.5.0beta07, which was
+This file was extended by libpng $as_me 1.5.0beta08, which was
 generated by GNU Autoconf 2.65.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
@@ -12099,7 +12099,7 @@
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
 ac_cs_version="\\
-libpng config.status 1.5.0beta07
+libpng config.status 1.5.0beta08
 configured by $0, generated by GNU Autoconf 2.65,
   with options \\"\$ac_cs_config\\"
 
diff --git a/configure.ac b/configure.ac
index ead43df..9de5e2b 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,12 +18,12 @@
 
 dnl Version number stuff here:
 
-AC_INIT([libpng], [1.5.0beta07], [png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng], [1.5.0beta08], [png-mng-implement@lists.sourceforge.net])
 AM_INIT_AUTOMAKE
 dnl stop configure from automagically running automake
 AM_MAINTAINER_MODE
 
-PNGLIB_VERSION=1.5.0beta07
+PNGLIB_VERSION=1.5.0beta08
 PNGLIB_MAJOR=1
 PNGLIB_MINOR=5
 PNGLIB_RELEASE=0
diff --git a/libpng-1.5.0beta07.txt b/libpng-1.5.0beta08.txt
similarity index 99%
rename from libpng-1.5.0beta07.txt
rename to libpng-1.5.0beta08.txt
index 1f62b18..5f85030 100644
--- a/libpng-1.5.0beta07.txt
+++ b/libpng-1.5.0beta08.txt
@@ -1,6 +1,6 @@
 libpng.txt - A description on how to use and modify libpng
 
- libpng version 1.5.0beta07 - February 19, 2010
+ libpng version 1.5.0beta08 - February 19, 2010
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2009 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.0beta07 - February 19, 2010
+ libpng versions 0.97, January 1998, through 1.5.0beta08 - February 19, 2010
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2009 Glenn Randers-Pehrson
 
@@ -899,7 +899,7 @@
 As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
 added.  It expands the sample depth without changing tRNS to alpha.
 
-As of libpng version 1.5.0beta07, not all possible expansions are supported.
+As of libpng version 1.5.0beta08, not all possible expansions are supported.
 
 In the following table, the 01 means grayscale with depth<8, 31 means
 indexed with depth<8, other numerals represent the color type, "T" means
@@ -3251,7 +3251,7 @@
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.0beta07 are Y2K compliant.  It is my belief that earlier
+upward through 1.5.0beta08 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has three year fields.  One is a 2-byte unsigned integer that
diff --git a/libpng.3 b/libpng.3
index 28d3696..cbbdd4c 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
 .TH LIBPNG 3 "February 19, 2010"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.0beta07
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.0beta08
 .SH SYNOPSIS
 \fI\fB
 
@@ -789,7 +789,7 @@
 .SH LIBPNG.TXT
 libpng.txt - A description on how to use and modify libpng
 
- libpng version 1.5.0beta07 - February 19, 2010
+ libpng version 1.5.0beta08 - February 19, 2010
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2009 Glenn Randers-Pehrson
@@ -800,7 +800,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.0beta07 - February 19, 2010
+ libpng versions 0.97, January 1998, through 1.5.0beta08 - February 19, 2010
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2009 Glenn Randers-Pehrson
 
@@ -1688,7 +1688,7 @@
 As of libpng version 1.2.9, png_set_expand_gray_1_2_4_to_8() was
 added.  It expands the sample depth without changing tRNS to alpha.
 
-As of libpng version 1.5.0beta07, not all possible expansions are supported.
+As of libpng version 1.5.0beta08, not all possible expansions are supported.
 
 In the following table, the 01 means grayscale with depth<8, 31 means
 indexed with depth<8, other numerals represent the color type, "T" means
@@ -4040,7 +4040,7 @@
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.0beta07 are Y2K compliant.  It is my belief that earlier
+upward through 1.5.0beta08 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has three year fields.  One is a 2-byte unsigned integer that
@@ -4216,7 +4216,7 @@
  1.4.1beta01-03      14    10401  14.so.14.1[.0]
  1.4.1rc01           14    10401  14.so.14.1[.0]
  1.4.1beta04-12      14    10401  14.so.14.1[.0]
- 1.5.0beta01-07      15    10500  15.so.15.1[.0]
+ 1.5.0beta01-08      15    10500  15.so.15.1[.0]
 
 Henceforth the source version will match the shared-library minor
 and patch numbers; the shared-library major version number will be
@@ -4272,7 +4272,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.5.0beta07 - February 19, 2010:
+Libpng version 1.5.0beta08 - February 19, 2010:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -4295,7 +4295,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.0beta07, February 19, 2010, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.0beta08, February 19, 2010, are
 Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
diff --git a/libpngpf.3 b/libpngpf.3
index c736fbc..f61350d 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
 .TH LIBPNGPF 3 "February 19, 2010"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.0beta07
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.0beta08
 (private functions)
 .SH SYNOPSIS
 \fB#include <png.h>\fP
diff --git a/png.c b/png.c
index 0b47114..7599428 100644
--- a/png.c
+++ b/png.c
@@ -18,7 +18,7 @@
 #include "pngpriv.h"
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_5_0beta07 Your_png_h_is_not_version_1_5_0beta07;
+typedef version_1_5_0beta08 Your_png_h_is_not_version_1_5_0beta08;
 
 /* Version information for C files.  This had better match the version
  * string defined in png.h.
@@ -552,13 +552,13 @@
 #else
 #ifdef __STDC__
    return ((png_charp) PNG_STRING_NEWLINE \
-     "libpng version 1.5.0beta07 - February 19, 2010" PNG_STRING_NEWLINE \
+     "libpng version 1.5.0beta08 - February 19, 2010" PNG_STRING_NEWLINE \
      "Copyright (c) 1998-2010 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
      "Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
      "Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
      PNG_STRING_NEWLINE);
 #else
-      return ((png_charp) "libpng version 1.5.0beta07 - February 19, 2010\
+      return ((png_charp) "libpng version 1.5.0beta08 - February 19, 2010\
       Copyright (c) 1998-2010 Glenn Randers-Pehrson\
       Copyright (c) 1996-1997 Andreas Dilger\
       Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.");
diff --git a/pngconf.h b/pngconf.h
index 55e225e..005b134 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
 
 /* pngconf.h - machine configurable file for libpng
  *
- * libpng version 1.5.0beta07 - February 19, 2010
+ * libpng version 1.5.0beta08 - February 19, 2010
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngpriv.h b/pngpriv.h
index 4ed174e..b1cbdc4 100644
--- a/pngpriv.h
+++ b/pngpriv.h
@@ -1,7 +1,7 @@
 
 /* pngpriv.h - private declarations for use inside libpng
  *
- * libpng version 1.5.0beta07 - February 19, 2010
+ * libpng version 1.5.0beta08 - February 19, 2010
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngtest.c b/pngtest.c
index c81a11e..6584274 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1625,4 +1625,4 @@
 }
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_5_0beta07 your_png_h_is_not_version_1_5_0beta07;
+typedef version_1_5_0beta08 your_png_h_is_not_version_1_5_0beta08;
diff --git a/projects/xcode/libpng.xcodeproj/project.pbxproj b/projects/xcode/libpng.xcodeproj/project.pbxproj
index daa2d84..163c462 100644
--- a/projects/xcode/libpng.xcodeproj/project.pbxproj
+++ b/projects/xcode/libpng.xcodeproj/project.pbxproj
@@ -226,7 +226,7 @@
 				COPY_PHASE_STRIP = NO;
 				DYLIB_COMPATIBILITY_VERSION = 15;
 				DYLIB_CURRENT_VERSION = 15;
-				FRAMEWORK_VERSION = 1.5.0beta07;
+				FRAMEWORK_VERSION = 1.5.0beta08;
 				GCC_PRECOMPILE_PREFIX_HEADER = NO;
 				GCC_PREFIX_HEADER = "";
 				INFOPLIST_FILE = Info.plist;
@@ -244,7 +244,7 @@
 			buildSettings = {
 				DYLIB_COMPATIBILITY_VERSION = 15;
 				DYLIB_CURRENT_VERSION = 15;
-				FRAMEWORK_VERSION = 1.5.0beta07;
+				FRAMEWORK_VERSION = 1.5.0beta08;
 				GCC_PRECOMPILE_PREFIX_HEADER = NO;
 				GCC_PREFIX_HEADER = "";
 				INFOPLIST_FILE = Info.plist;
diff --git a/scripts/README.txt b/scripts/README.txt
index a0aedd5..95903b9 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,8 +1,8 @@
 
-Makefiles for  libpng version 1.5.0beta07 - February 19, 2010
+Makefiles for  libpng version 1.5.0beta08 - February 19, 2010
 
  makefile.linux    =>  Linux/ELF makefile
-                       (gcc, creates libpng15.so.15.1.5.0beta07)
+                       (gcc, creates libpng15.so.15.1.5.0beta08)
  makefile.gcc      =>  Generic makefile (gcc, creates static libpng.a)
  makefile.knr      =>  Archaic UNIX Makefile that converts files with
                        ansi2knr (Requires ansi2knr.c from
@@ -20,7 +20,7 @@
  makefile.dec      =>  DEC Alpha UNIX makefile
  makefile.dj2      =>  DJGPP 2 makefile
  makefile.elf      =>  Linux/ELF makefile symbol versioning,
-                       gcc, creates libpng15.so.15.1.5.0beta07)
+                       gcc, creates libpng15.so.15.1.5.0beta08)
  makefile.freebsd  =>  FreeBSD makefile
  makefile.gcc      =>  Generic gcc makefile
  makefile.hpgcc    =>  HPUX makefile using gcc
@@ -36,12 +36,12 @@
  makefile.os2      =>  OS/2 Makefile (gcc and emx, requires pngos2.def)
  makefile.sco      =>  For SCO OSr5  ELF and Unixware 7 with Native cc
  makefile.sggcc    =>  Silicon Graphics (gcc,
-                       creates libpng15.so.15.1.5.0beta07)
+                       creates libpng15.so.15.1.5.0beta08)
  makefile.sgi      =>  Silicon Graphics IRIX makefile (cc, creates static lib)
  makefile.solaris  =>  Solaris 2.X makefile (gcc,
-                       creates libpng15.so.15.1.5.0beta07)
+                       creates libpng15.so.15.1.5.0beta08)
  makefile.so9      =>  Solaris 9 makefile (gcc,
-                       creates libpng15.so.15.1.5.0beta07)
+                       creates libpng15.so.15.1.5.0beta08)
  makefile.std      =>  Generic UNIX makefile (cc, creates static libpng.a)
  makefile.sunos    =>  Sun makefile
  makefile.32sunu   =>  Sun Ultra 32-bit makefile
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index 25d2432..222f6dc 100755
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
 
 # Modeled after libxml-config.
 
-version=1.5.0beta07
+version=1.5.0beta08
 prefix=""
 libdir=""
 libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index df7626c..75f48d8 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@
 
 Name: libpng
 Description: Loads and saves PNG files
-Version: 1.5.0beta07
+Version: 1.5.0beta08
 Libs: -L${libdir} -lpng15
 Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index 4a78606..510a59a 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@
 
 LIB=	png15
 SHLIB_MAJOR=	0
-SHLIB_MINOR=	1.5.0beta07
+SHLIB_MINOR=	1.5.0beta08
 SRCS=	png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index 834bb4e..e3c32a8 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@
 
 LIB=	png
 SHLIB_MAJOR=	3
-SHLIB_MINOR=	1.5.0beta07
+SHLIB_MINOR=	1.5.0beta08
 SRCS=	png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index 6b4a5d5..b3359e6 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@
 MANDIR= ${PREFIX}/man/cat
 
 SHLIB_MAJOR=	0
-SHLIB_MINOR=	1.5.0beta07
+SHLIB_MINOR=	1.5.0beta08
 
 LIB=	png
 SRCS=	png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/png32ce.def b/scripts/png32ce.def
index 8a006c5..8c5a93f 100644
--- a/scripts/png32ce.def
+++ b/scripts/png32ce.def
@@ -15,7 +15,7 @@
  png_get_int_32
 
 EXPORTS
-;Version 1.5.0beta07
+;Version 1.5.0beta08
   png_build_grayscale_palette  @1
 ;  png_check_sig        @2
   png_chunk_error      @3
diff --git a/scripts/pngos2.def b/scripts/pngos2.def
index ba07de5..6b46f60 100644
--- a/scripts/pngos2.def
+++ b/scripts/pngos2.def
@@ -2,7 +2,7 @@
 ; PNG.LIB module definition file for OS/2
 ;----------------------------------------
 
-; Version 1.5.0beta07
+; Version 1.5.0beta08
 
 LIBRARY		PNG
 DESCRIPTION	"PNG image compression library for OS/2"
diff --git a/scripts/pngwin.def b/scripts/pngwin.def
index 4ba8ded..3d1f3be 100644
--- a/scripts/pngwin.def
+++ b/scripts/pngwin.def
@@ -5,7 +5,7 @@
 LIBRARY
 
 EXPORTS
-;Version 1.5.0beta07
+;Version 1.5.0beta08
   png_build_grayscale_palette
   png_chunk_error
   png_chunk_warning
diff --git a/png.h b/png.h
index 517d0cd..e8ba8c1 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.5.0beta07 - February 19, 2010
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *  libpng versions 0.97, January 1998, through 1.5.0beta07 - February 19, 2010: Glenn
  *  See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -137,7 +137,7 @@
  *    1.4.1beta01-03          14    10401  14.so.14.1[.0]
  *    1.4.1rc01               14    10401  14.so.14.1[.0]
  *    1.4.1beta04-12          14    10401  14.so.14.1[.0]
- *    1.5.0beta01-07          15    10500  15.so.15.0[.0]
+ *    1.5.0beta01-08          15    10500  15.so.15.0[.0]
  *
  *    Henceforth the source version will match the shared-library major
  *    and minor numbers; the shared-library major version number will be
@@ -169,7 +169,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.5.0beta07, February 19, 2010, are
  * Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -287,7 +287,7 @@
  *    an official declaration.
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
  *    upward through 1.5.0beta07 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *
  *    Libpng only has three year fields.  One is a 2-byte unsigned integer
@@ -343,9 +343,9 @@
  */
 
 /* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.0beta07"
+#define PNG_LIBPNG_VER_STRING "1.5.0beta08"
 #define PNG_HEADER_VERSION_STRING \
-   " libpng version 1.5.0beta07 - February 19, 2010\n"
+   " libpng version 1.5.0beta08 - February 19, 2010\n"
 
 #define PNG_LIBPNG_VER_SONUM   15
 #define PNG_LIBPNG_VER_DLLNUM  15
@@ -358,7 +358,7 @@
  * PNG_LIBPNG_VER_STRING, omitting any leading zero:
  */
 
-#define PNG_LIBPNG_VER_BUILD  07
+#define PNG_LIBPNG_VER_BUILD  08
 
 /* Release Status */
 #define PNG_LIBPNG_BUILD_ALPHA    1
@@ -796,7 +796,7 @@
 /* This triggers a compiler error in png.c, if png.c and png.h
  * do not agree upon the version number.
  */
-typedef png_structp version_1_5_0beta07;
+typedef png_structp version_1_5_0beta08;
 
 typedef png_struct FAR * FAR * png_structpp;
 
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.5.0beta07 - February 19, 2010
+ * libpng version 1.5.0beta08 - February 19, 2010
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *  libpng versions 0.97, January 1998, through 1.5.0beta07 - February 19, 2010: Glenn
+ *  libpng versions 0.97, January 1998, through 1.5.0beta08 - February 19, 2010: Glenn
  *  See also "Contributing Authors", below.
  *
@@ -169,7 +169,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.5.0beta07, February 19, 2010, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.0beta08, February 19, 2010, are
  * Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
@@ -287,7 +287,7 @@
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
- *    upward through 1.5.0beta07 are Y2K compliant.  It is my belief that earlier
+ *    upward through 1.5.0beta08 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *